Build and install spacy locally

1. Navigate to spacy/
2. pip3 install -r requirements.txt
3. python3 setup.py build_ext --inplace (for error regarding cython use sudo - it worked for me)
4. Install from source: sudo python3 setup.py install 
5. Check version of spacy: pip3 show spacy (should have a dev version)


Install spacy named entity recognition multi language
python -m spacy download xx_ent_wiki_sm

